bug#52890: Bogus gpl(7) man page in 'musl-cross' package

2021-12-29 Thread Mark H Weaver
I built the 'musl-cross' package on my personal branch[*] and found that
the build output contains a bogus "share/man/man7/gpl.7" file.  The file
contains only 10 bytes: "timestamp\n".

   Mark

[*] My personal branch is admittedly very far from the current 'master'
branch, but I doubt it makes a difference for purposes of this bug.

-- 
Disinformation flourishes because many people care deeply about injustice
but very few check the facts.  Ask me about .





bug#52853: Error when trying to upgrade packages

2021-12-29 Thread Cameron Chaparro
As it turns out, I was able to narrow the problem down to having 0ad
installed and needing to be upgraded.

I determined this by manually upgrading everything (running `guix system
reconfigure /etc/config.scm didn't change anything, nor did
force-restarting guix-daemon using `herd`). I'm not sure what the specific
issue is - increasing the verbosity level didn't actually give any more
output - so I just uninstalled that package.

For my part, I think this can be closed (I'm not sure how to do that) but
the 0ad package seems to be the one that has that issue.


bug#50356: python-hy / python-funcparserlib / tox config file

2021-12-29 Thread Vinicius Monego
Fixed in 06e39eafd7d8279b0b97424c9c32f60a31bfce30 by updating
funcparserlib to the alpha version and Hy to 0.20.0. When the next
stable version of funcparserlib is released I will do another update.






bug#45416: Fix dead URL links on website

2021-12-29 Thread Leo Famulari
On Fri, Dec 25, 2020 at 02:09:54PM +0800, Peng Mei Yu wrote:
> Hi,
> 
> I am translating the guix.gnu.org website.  I found several dead links
> on the page.
> 
> They are at the bottom of https://guix.gnu.org/en/donate/.
> 
> 1. GNU España
> 2. FSF France
> 3. Free Secure Network Systems Group
> 
> Please fix them.  Thank you.

FSF France is back online.

I de-linked the other two with commit
3e846ee5dc14aadfb65a0592011de2d0888cb5eb

https://git.savannah.gnu.org/cgit/guix/guix-artwork.git/commit/?id=3e846ee5dc14aadfb65a0592011de2d0888cb5eb





bug#44382: Updating the guix package triggers a full Git clone of guix.git

2021-12-29 Thread Leo Famulari
On Sun, Nov 29, 2020 at 10:24:18PM -0500, Maxim Cournoyer wrote:
> I had researched this before and the option the git server is missing is
> uploadpack.allowAnySHA1InWant [0].  Unfortunately last I check in
> #savannah their machine (vcs0) is using an older Trisquel stuck with git
> v2.11.0, one patch version before when the above feature was introduced
> (v2.11.1)!  If I understood correctly, they have a new VM vcs2 but it
> needs to be completely setup before they can switch.

Savannah is now using Git version 2.17.1. I wonder if we can have this
option enabled now? I checked and the problem described by this bug
still exists.





bug#41120: uvesafb service is unsupported on aarch64

2021-12-29 Thread Tobias Geerinckx-Rice via Bug reports for GNU Guix
I wrote the attached quick fix, then noticed that this bug is 
paired with #29296 which seems to propose a whole 'nother 
mechanism?


I'm not sure I grok the latter's advantage yet.

Kind regards,

T G-R

From 29d6ce59a0f3953de627d110adaa7978051ca077 Mon Sep 17 00:00:00 2001
From: Tobias Geerinckx-Rice 
Date: Wed, 29 Dec 2021 23:01:11 +0100
Subject: [PATCH] install: Add uvesafb service only on x86.
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

* gnu/system/install.scm (%installation-services): Turn into…
(installation-services): …this procedure.  Adjust sole user.
Add the uvesafb-service-type only when targetting x86.
---
 gnu/system/install.scm | 25 +++--
 1 file changed, 15 insertions(+), 10 deletions(-)

-- 
2.34.0



signature.asc
Description: PGP signature


bug#52831: [installer] Locale problems with nss-certs

2021-12-29 Thread Mathieu Othacehe


Hello Leo,

> Then I copied the image out of the store and booted it in QEMU.
>
> But, I still had the problem during installation. Did I miss a step?

No, I just sent you a wrong version of my patch, sorry about
that. LC_ALL needs to be set as an environment variable and with a
setlocale call.

--8<---cut here---start->8---
diff --git a/gnu/installer/utils.scm b/gnu/installer/utils.scm
index bb97bc5560..24c16e7e12 100644
--- a/gnu/installer/utils.scm
+++ b/gnu/installer/utils.scm
@@ -97,10 +97,13 @@ (define (pause)
   ;; least give us translated messages.
   (if supported?
   (setenv "LC_ALL" locale)
-  (setenv "LANGUAGE"
-  (string-take locale
-   (or (string-index locale #\_)
-   (string-length locale)))
+  (begin
+(setlocale LC_ALL "en_US.utf8")
+(setenv "LC_ALL" "en_US.utf8")
+(setenv "LANGUAGE"
+(string-take locale
+ (or (string-index locale #\_)
+ (string-length locale
--8<---cut here---end--->8---

Thanks,

Mathieu





bug#52831: [installer] Locale problems with nss-certs

2021-12-29 Thread Leo Famulari
On Wed, Dec 29, 2021 at 06:26:05PM +0100, Mathieu Othacehe wrote:
> > While testing the Guix System installer, I noticed that installation of
> > nss-certs has some problems that seem related to locales.
> 
> What locale did you pick in the installer?

I chose the first items in the lists, which are "English" of the
territory "Antigua and Barbuda". That's "en_AG.utf8"

When I use "en_US.utf8", the problem does not occur.

> The following patch fixes it for me.
> 
> --8<---cut here---start->8---
> diff --git a/gnu/installer/utils.scm b/gnu/installer/utils.scm
> index bb97bc5560..d745996a3a 100644
> --- a/gnu/installer/utils.scm
> +++ b/gnu/installer/utils.scm
> @@ -97,10 +97,12 @@ (define (pause)
>;; least give us translated messages.
>(if supported?
>(setenv "LC_ALL" locale)
> -  (setenv "LANGUAGE"
> -  (string-take locale
> -   (or (string-index locale #\_)
> -   (string-length locale)))
> +  (begin
> +(setlocale LC_ALL "en_US.utf8")
> +(setenv "LANGUAGE"
> +(string-take locale
> + (or (string-index locale #\_)
> + (string-length locale
>  
>(guard (c ((invoke-error? c)
>   (newline)
> --8<---cut here---end--->8---
> 
> WDYT?

I applied this patch to my Git repo and built a new installer like this:

`./pre-inst-env guix system image -t uncompressed-iso9660 
--label="GUIX_x86_64-linux-leo" --system=x86_64-linux gnu/system/install.scm`

Then I copied the image out of the store and booted it in QEMU.

But, I still had the problem during installation. Did I miss a step?





bug#52879: [installer] Can we remove locale-2.31 from locale-libcs in the upcoming release?

2021-12-29 Thread Leo Famulari
I noticed that the installer built from current master includes locales
from glibc 2.31 and 2.33, because they are both in
%default-locale-libcs.

Will we still need this workaround for the upcoming release? Presumably,
new installations will not include anything that uses glibc 2.31.





bug#52831: [installer] Locale problems with nss-certs

2021-12-29 Thread Mathieu Othacehe


Hello Leo,

> While testing the Guix System installer, I noticed that installation of
> nss-certs has some problems that seem related to locales.

What locale did you pick in the installer?

I think the issue lies in the (gnu installer utils) module, run-command
procedure:

--8<---cut here---start->8---
  (when locale
(let ((supported? (false-if-exception
   (setlocale LC_ALL locale
  ;; If LOCALE is not supported, then set LANGUAGE, which might at
  ;; least give us translated messages.
  (if supported?
  (setenv "LC_ALL" locale)
  (setenv "LANGUAGE"
  (string-take locale
   (or (string-index locale #\_)
   (string-length locale)))
--8<---cut here---end--->8---

If you pick a locale such as en_AG.utf8 which is not supported by the
glibc-utf8-locales package, then supported? is #f, which means that
LC_ALL is never set.

The following patch fixes it for me.

--8<---cut here---start->8---
diff --git a/gnu/installer/utils.scm b/gnu/installer/utils.scm
index bb97bc5560..d745996a3a 100644
--- a/gnu/installer/utils.scm
+++ b/gnu/installer/utils.scm
@@ -97,10 +97,12 @@ (define (pause)
   ;; least give us translated messages.
   (if supported?
   (setenv "LC_ALL" locale)
-  (setenv "LANGUAGE"
-  (string-take locale
-   (or (string-index locale #\_)
-   (string-length locale)))
+  (begin
+(setlocale LC_ALL "en_US.utf8")
+(setenv "LANGUAGE"
+(string-take locale
+ (or (string-index locale #\_)
+ (string-length locale
 
   (guard (c ((invoke-error? c)
  (newline)
--8<---cut here---end--->8---

WDYT?

Thanks,

Mathieu





bug#52836: "guix import pypi" fails with "Failed to extract file from wheel" and "no requires.txt file found"

2021-12-29 Thread zimoun
Hi,

On Mon, 27 Dec 2021 at 22:10, bbb ee  wrote:

> ```
> guix import: warning: Failed to extract file:
> PyPortfolioOpt-1.5.1.dist-info/METADATA from wheel.
> guix import: warning: Cannot guess requirements from source archive: no
> requires.txt file found.
> ```

Is it a bug on Guix side or upstream?  Because it seems that upstream
does not provide metadata information, at least, as usually expected.

Well, I have not yet inspected the PyPI package but it seems possible
that it is incorrectly packaged with the Setuptools standard.


> ## additional information
> This user has encountered a similar issue for "guix import pypi httpie"
> https://www.mail-archive.com/bug-guix@gnu.org/msg14277.html
>
> However "guix import pypi httpie" runs for my version of guix.

Well, “guix import pypi httpie” works for me.


Cheers,
simon





bug#52305: calibre unable to fetch news

2021-12-29 Thread rdes via Bug reports for GNU Guix
Hello Michael,

I am running guix on fedora 35.

When I run `SSL_CERT_DIR=/etc/ssl/certs calibre` I get:

Fetch news from CNET News
Conversion options changed from defaults:
  verbose: 2
  output_profile: 'generic_eink'
Resolved conversion options
calibre version: 5.21.0
{'asciiize': False,
 'author_sort': None,
 'authors': None,
 'base_font_size': 0,
 'book_producer': None,
 'change_justification': 'original',
 'chapter': None,
 'chapter_mark': 'pagebreak',
 'comments': None,
 'cover': None,
 'debug_pipeline': None,
 'dehyphenate': True,
 'delete_blank_paragraphs': True,
 'disable_font_rescaling': False,
 'dont_download_recipe': False,
 'dont_split_on_page_breaks': True,
 'duplicate_links_in_toc': False,
 'embed_all_fonts': False,
 'embed_font_family': None,
 'enable_heuristics': False,
 'epub_flatten': False,
 'epub_inline_toc': False,
 'epub_toc_at_end': False,
 'epub_version': '2',
 'expand_css': False,
 'extra_css': None,
 'extract_to': None,
 'filter_css': None,
 'fix_indents': True,
 'flow_size': 260,
 'font_size_mapping': None,
 'format_scene_breaks': True,
 'html_unwrap_factor': 0.4,
 'input_encoding': None,
 'input_profile': ,
 'insert_blank_line': False,
 'insert_blank_line_size': 0.5,
 'insert_metadata': False,
 'isbn': None,
 'italicize_common_cases': True,
 'keep_ligatures': False,
 'language': None,
 'level1_toc': None,
 'level2_toc': None,
 'level3_toc': None,
 'line_height': 0,
 'linearize_tables': False,
 'lrf': False,
 'margin_bottom': 5.0,
 'margin_left': 5.0,
 'margin_right': 5.0,
 'margin_top': 5.0,
 'markup_chapter_headings': True,
 'max_toc_links': 50,
 'minimum_line_height': 120.0,
 'no_chapters_in_toc': False,
 'no_default_epub_cover': False,
 'no_inline_navbars': False,
 'no_svg_cover': False,
 'output_profile': ,
 'page_breaks_before': None,
 'prefer_metadata_cover': False,
 'preserve_cover_aspect_ratio': False,
 'pretty_print': True,
 'pubdate': None,
 'publisher': None,
 'rating': None,
 'read_metadata_from_opf': None,
 'remove_fake_margins': True,
 'remove_first_image': False,
 'remove_paragraph_spacing': False,
 'remove_paragraph_spacing_indent_size': 1.5,
 'renumber_headings': True,
 'replace_scene_breaks': '',
 'search_replace': None,
 'series': None,
 'series_index': None,
 'smarten_punctuation': False,
 'sr1_replace': '',
 'sr1_search': '',
 'sr2_replace': '',
 'sr2_search': '',
 'sr3_replace': '',
 'sr3_search': '',
 'start_reading_at': None,
 'subset_embedded_fonts': False,
 'tags': None,
 'test': False,
 'timestamp': None,
 'title': None,
 'title_sort': None,
 'toc_filter': None,
 'toc_threshold': 6,
 'toc_title': None,
 'transform_css_rules': None,
 'unsmarten_punctuation': False,
 'unwrap_lines': True,
 'use_auto_toc': False,
 'verbose': 2}
InputFormatPlugin: Recipe Input running
Downloading recipe urn: builtin:cnetnews
Trying to get latest version of recipe: cnetnews
Using user agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 
(KHTML, like Gecko) Chrome/80.0.3987.87 Safari/537.36
Failed feed: CNET News
Traceback (most recent call last):
  File 
"/gnu/store/8jz60fbr93nbkdicgw2l3ijd38g9pf39-python-mechanize-0.4.5/lib/python3.8/site-packages/mechanize/_urllib2_fork.py",
 line 1229, in do_open
h.request(str(req.get_method()), str(req.get_selector()), req.data,
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 1245, in request
self._send_request(method, url, body, headers, encode_chunked)
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 1291, in _send_request
self.endheaders(body, encode_chunked=encode_chunked)
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 1240, in endheaders
self._send_output(message_body, encode_chunked=encode_chunked)
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 1008, in _send_output
self.send(msg)
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 948, in send
self.connect()
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/http/client.py",
 line 1414, in connect
self.sock = self._context.wrap_socket(self.sock,
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/ssl.py",
 line 500, in wrap_socket
return self.sslsocket_class._create(
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/ssl.py",
 line 1040, in _create
self.do_handshake()
  File 
"/gnu/store/sd2ic7bpv8fx3imy1j8xcjclx71sv6q0-python-3.8.2/lib/python3.8/ssl.py",
 line 1309, in do_handshake
self._sslobj.do_handshake()
ssl.SSLCertVerificationError: [SSL: CERTIFICATE_VERIFY_FAILED] certificate 
verify failed: unable to get local issuer certificate (_ssl.c:1108)

During handling of the above exception, another exception occurred:

Traceback (most recent call last):
  File 
"/gnu/sto

bug#52847: Guitarix build fails

2021-12-29 Thread Mathieu Othacehe


Hello,

> Hello, I'm currently unable to build `guitarix`. This only started
> happening after the recent `core-updates-frozen` match, at least I
> believe so.

Fixed by updating the package to the 0.43.1 release with
002442b2209b0953dd209e6219696a8758ceceb2.

Thanks,

Mathieu





bug#52862: Clarify note about sudo in 3.7 After System Installation

2021-12-29 Thread Akira Kyle
Hi,

I'm trying to get going with guixsd for the first time and I just
spent awhile trying to figure out what was going wrong trying to run
'guix pull' and 'guix system reconfigure /etc/config.scm'.

The issue was that I was running both in shell obtained via 'sudo su'
from my user shell. I had read the note about this in section "3.7
After System Installation" and thought since, following the note, I
was running both in a root shell, this would be fine. Coming from nix,
this is fine, however I see now that the environment and path are
incorrect in a 'sudo su' shell as the guix that was being used was the
system guix from /run/current-system/profile and not
/root/.config/guix/current which led to the effective system downgrade
that running guix system reconfigure kept warning about.

I would suggest updating the documentation to explicitly say 'sudo su'
should not be used since I expect there are many others like me who
are ignorant to the differences between 'sudo su' and 'sudo -i'

Thanks,
Akira





bug#52869: xpra 4.3 appears to be broken

2021-12-29 Thread t



Hello guix.

Relatively fresh guix, pulled 2 days ago.


$ guix describe
Generation 10   Dec 27 2021 15:36:01(current)
 guix 9e9489f
   repository URL: https://git.savannah.gnu.org/git/guix.git
   branch: master
   commit: 9e9489fb11ac73e51abe293235738d70365affa9


Installing xpra 4.3 package as described in xorg.scm. Looks like 
it pulls a substitute with upstream log at 
https://ci.guix.gnu.org/log/sy4ar80nk2hq32axl4by7bgmns6bcwl0-xpra-4.3 
where I don't really see anything pop as suspicious


Attempting to start a session however fails:

$ guix environment --ad-hoc xpra --pure -- xpra start :100
2021-12-29 09:44:20,712 Warning: cannot load cython bencode 
module: No module named 'xpra.net.bencode.cython_bencode'

Warning: using '/run/user/1000' as XDG_RUNTIME_DIR
xpra initialization error:
start is not supported by this local installation


I reported this to xpra maintainer first thinking the problem was 
there https://github.com/Xpra-org/xpra/issues/3403 but they confirmed that our build was likely incomplete. As per 
above you can already tell that cython_bencode is in fact missing 
and indeed I don't see it in the built artefact in the store, 
though it is present in the source repo. "start not supported" 
above indicates we have bigger issues, as per maintainer we 
probably don't have access to the server component. Briefly 
grepping for that warning origin, looks like we're likely failing 
the supports_server test in xpra/scripts/parsing.py:


if supports_server:
   try:
   from xpra.x11.bindings.wait_for_x_server import 
   wait_for_x_server#@UnresolvedImport @UnusedImport

   except ImportError:
   supports_server = False


I am way out of my depth to debug this on my own, but happy to try 
and assist.


I believe the previous build of 4.2.smth worked for me, so must be 
something new. Is there an easy way to downgrade this package 
without rolling entire guix? Do I use inferior guix for that 
somehow?


Happy to follow this up with guix xpra package maintainer if only 
I could figure who that courageous soul was.


Thanks





bug#52667: System reconfiguration fails to build linux-modules.drv

2021-12-29 Thread Julien L.

Dear Guix team,

I am using linux-libre in version 4.19. In this version there are no 
modules named framebuffer_coreboot and simplefb.


So system reconfiguration complains about framebuffer_corebook being not 
found.


I of course applied the workaround (specifying initrd-modules with 
%base-initrd-modules minus framebuffer_coreboot and simplefb) but this 
is not really nice.


I also understand the constraints.

Would it be a valid solution that linux-modules.scm discards modules 
which are not found (instead of returning an error and stopping)?


Thanks,

diff --git a/gnu/system/install.scm b/gnu/system/install.scm
index 073d7df1db..36c24992bd 100644
--- a/gnu/system/install.scm
+++ b/gnu/system/install.scm
@@ -3,7 +3,7 @@
 ;;; Copyright © 2015 Mark H Weaver 
 ;;; Copyright © 2016 Andreas Enge 
 ;;; Copyright © 2017 Marius Bakke 
-;;; Copyright © 2017, 2019 Tobias Geerinckx-Rice 
+;;; Copyright © 2017, 2019, 2021 Tobias Geerinckx-Rice 
 ;;; Copyright © 2020 Florian Pelz 
 ;;; Copyright © 2020 Efraim Flashner 
 ;;;
@@ -33,6 +33,7 @@ (define-module (gnu system install)
   #:use-module (guix modules)
   #:use-module ((guix packages) #:select (package-version))
   #:use-module ((guix store) #:select (%store-prefix))
+  #:use-module (guix utils)
   #:use-module (gnu installer)
   #:use-module (gnu system locale)
   #:use-module (gnu services avahi)
@@ -303,7 +304,7 @@ (define uvesafb-service-type
 "Load the @code{uvesafb} kernel module with the right options.")
(default-value #t)))
 
-(define %installation-services
+(define (installation-services)
   ;; List of services of the installation system.
   (let ((motd (plain-file "motd" "
 \x1b[1;37mWelcome to the installation of GNU Guix!\x1b[0m
@@ -320,7 +321,9 @@ (define (normal-tty tty)
 (define bare-bones-os
   (load "examples/bare-bones.tmpl"))
 
-(list (service virtual-terminal-service-type)
+(append
+(list
+  (service virtual-terminal-service-type)
 
   (service kmscon-service-type
(kmscon-configuration
@@ -426,13 +429,15 @@ (define bare-bones-os
   glibc-utf8-locales
   texinfo
   guile-3.0)
-%default-locale-libcs))
+%default-locale-libcs)))
 
-  ;; Machines without Kernel Mode Setting (those with many old and
-  ;; current AMD GPUs, SiS GPUs, ...) need uvesafb to show the GUI
-  ;; installer.  Some may also need a kernel parameter like nomodeset
-  ;; or vga=793, but we leave that for the user to specify in GRUB.
-  (service uvesafb-service-type
+(if (or (target-x86-32?) (target-x86-64?))
+;; x86 machines without Kernel Mode Setting (those with many old and
+;; current AMD GPUs, SiS GPUs, ...) need uvesafb to show the GUI
+;; installer.  Some may also need a kernel parameter like nomodeset
+;; or vga=793, but we leave that for the user to specify in GRUB.
+(list (service uvesafb-service-type))
+'()
 
 (define %issue
   ;; Greeting.
@@ -496,7 +501,7 @@ (define installation-os
   (comment "Guest of GNU"
 
 (issue %issue)
-(services %installation-services)
+(services (installation-services))
 
 ;; We don't need setuid programs, except for 'passwd', which can be handy
 ;; if one is to allow remote SSH login to the machine being installed.
--
Julien L.






bug#52837: We need deeper research

2021-12-29 Thread Nicolas Goaziou
Hello,

Evgenii Lepikhin via Bug reports for GNU Guix  writes:

> Now it is fixed.

Closing it, then. Thanks for the feedback.

Regards,
-- 
Nicolas Goaziou





bug#52837: We need deeper research

2021-12-29 Thread Evgenii Lepikhin via Bug reports for GNU Guix


On 2021-12-28 14:41, Leo Famulari wrote:

>> We need to update both rust-aom-sys to == 0.3.0 and rav1e to >= 0.5.0.
>
> Okay, that's good to know. I hope that somebody will try it and report
> back.

Now it is fixed.

Thank you.


-- 
QA automation teamlead at Mail.ru.





bug#41120: uvesafb service is unsupported on aarch64

2021-12-29 Thread Efraim Flashner
On Tue, Dec 28, 2021 at 09:30:27PM -0500, Leo Famulari wrote:
> On Thu, May 07, 2020 at 08:40:15AM +0300, Efraim Flashner wrote:
> > the uvesafb-service which was added to the installation image isn't
> > supported on aarch64 (or probably any non-x86 system) and causes the
> > creation of an installation image to fail.
> 
> This is still an issue, right?

I believe so. Borrowing from the manual I tried the following command
and it showed that it was going to build v86d.

guix system image --system=armhf-linux -e '((@ (gnu system install) 
os-with-u-boot) (@ (gnu system install) installation-os) 
"A20-OLinuXino-Lime2")' -n

-- 
Efraim Flashner  רנשלפ םירפא
GPG key = A28B F40C 3E55 1372 662D  14F7 41AA E7DC CA3D 8351
Confidentiality cannot be guaranteed on emails sent or received unencrypted


signature.asc
Description: PGP signature